Weaviate Packages
=================

.. automodule:: weaviate
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   weaviate.backup
   weaviate.batch
   weaviate.classification
   weaviate.cluster
   weaviate.collections
   weaviate.connect
   weaviate.contextionary
   weaviate.data
   weaviate.gql
   weaviate.proto
   weaviate.schema

Submodules
----------

weaviate.auth module
--------------------

.. automodule:: weaviate.auth
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.classes module
-----------------------

.. automodule:: weaviate.classes
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.client module
----------------------

.. automodule:: weaviate.client
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.config module
----------------------

.. automodule:: weaviate.config
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.embedded module
------------------------

.. automodule:: weaviate.embedded
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.error\_msgs module
---------------------------

.. automodule:: weaviate.error_msgs
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.exceptions module
--------------------------

.. automodule:: weaviate.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.types module
---------------------

.. automodule:: weaviate.types
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.util module
--------------------

.. automodule:: weaviate.util
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.warnings module
------------------------

.. automodule:: weaviate.warnings
   :members:
   :undoc-members:
   :show-inheritance:
